"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AdvertisingIdPlugin = void 0;
var _analyticsReactNative = require("@segment/analytics-react-native");
var _reactNative = require("react-native");
class AdvertisingIdPlugin extends _analyticsReactNative.Plugin {
  type = _analyticsReactNative.PluginType.enrichment;
  queuedEvents = [];
  advertisingId = undefined;
  isLimitAdTracking = false;
  configure(analytics) {
    if (_reactNative.Platform.OS !== 'android') {
      return;
    }
    this.analytics = analytics;
    // Create an array of promises for fetching advertising ID and limit ad tracking status
    const advertisingIdPromise = this.fetchAdvertisingId();
    const limitAdTrackingStatusPromise = this.fetchLimitAdTrackingStatus();
    // Wait for both promises to resolve
    Promise.all([advertisingIdPromise, limitAdTrackingStatusPromise]).then(([id, status]) => {
      //handle advertisingID
      if (id === null) {
        // Need to check this condition
        void analytics.track('LimitAdTrackingEnabled (Google Play Services) is enabled');
      } else {
        this.advertisingId = id;
      }
      //handle isLimitAdTrackingEnableStatus
      this.isLimitAdTracking = status;

      // Call setContext after both values are available
      void this.setContext(this.advertisingId, status);
    }).catch(error => this.handleError(error));
  }
  execute(event) {
    if (this.advertisingId === undefined) {
      this.queuedEvents.push(event);
    } else {
      return event;
    }
    return;
  }
  async setContext(id, isLimitAdTrackingEnableStatus) {
    try {
      await this.analytics?.context.set({
        device: {
          advertisingId: id,
          adTrackingEnabled: !isLimitAdTrackingEnableStatus
        }
      });
      this.sendQueued();
    } catch (error) {
      const message = 'AdvertisingID failed to set context';
      this.analytics?.reportInternalError(new _analyticsReactNative.SegmentError(_analyticsReactNative.ErrorType.PluginError, message, error));
      this.analytics?.logger.warn(`${message}: ${JSON.stringify(error)}`);
    }
  }
  sendQueued() {
    this.queuedEvents.forEach(event => {
      void this.analytics?.process(event);
    });
    this.queuedEvents = [];
  }
  fetchAdvertisingId() {
    return (0, _analyticsReactNative.getNativeModule)('AnalyticsReactNativePluginAdvertisingId')?.getAdvertisingId();
  }
  fetchLimitAdTrackingStatus() {
    return (0, _analyticsReactNative.getNativeModule)('AnalyticsReactNativePluginAdvertisingId')?.getIsLimitAdTrackingEnableStatus();
  }
  handleError(error) {
    this.analytics?.reportInternalError(new _analyticsReactNative.SegmentError(_analyticsReactNative.ErrorType.PluginError, 'Error retrieving AdvertisingID', error));
  }
}
exports.AdvertisingIdPlugin = AdvertisingIdPlugin;
//# sourceMappingURL=AdvertisingIdPlugin.js.map